# $Id: minipy.py,v 1.2 2001/12/26 14:45:55 jfontain Exp $


from string import split

__version__ = split('$Revision: 1.2 $')[1]

form = {}
data = []

form['updates'] = 0
form['columns'] = [
    {'label': 'column', 'type': 'ascii', 'message': 'column title'}
]
form['pollTimes'] = [5, 10, 20, 30, 60]
form['sort'] = {0: 'decreasing'}
form['helpText'] = 'This is a minimal demonstration module for moodss.'

def update():
    global form, data
    data = [['data']]
    form['updates'] = form['updates'] + 1
